/***************************************************************************
 *   Copyright (C) 2008 by Bram Schoenmakers <bramschoenmakers@kde.nl>     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef PLASMA_APPLET_COMMAND_WATCH_H
#define PLASMA_APPLET_COMMAND_WATCH_H

#include <KProcess>
#include <Plasma/Applet>

class QLabel;

class KColorButton;
class KComboBox;
class KFontRequester;
class KIntNumInput;
class KLineEdit;
class KProcess;

/**
 * \short The CommandWatch applet shows the output of a command, eventually with interval.
 */
class CommandWatch : public Plasma::Applet
{
  Q_OBJECT
  public:
    CommandWatch( QObject* p_parent, const QVariantList& p_args );
    ~CommandWatch();

    virtual QList<QAction *> contextualActions();
  public slots:
    void init();
  protected:
    void createConfigurationInterface( KConfigDialog *p_parent );
  private slots:
    void loadConfig();
    void saveConfig();
    void executeCommand();
    void gotStdOut();
  private:
    void paintInterface( QPainter *p_painter, const QStyleOptionGraphicsItem *p_option, const QRect &p_contentsRect );

    bool m_forceUpdate;

    // main
    QTimer *m_timer;
    KProcess m_proc;
    QString m_output;
    QDateTime m_nextUpdate;
    QList<QAction *> m_actions;

    // configuration
    QString m_command;
    KLineEdit *m_command_edit;

    int m_timeout;
    KIntNumInput *m_interval_value;
    KComboBox *m_interval_combo;

    QFont m_font;
    KFontRequester *m_kfr;

    QColor m_fontcolor;
    KColorButton *m_colorbutton;
};

#endif // PLASMA_APPLET_COMMAND_WATCH_H
